from distutils.core import setup

setup(
    name='Gloo',
    version='0.0.1',
    author='Trent Hauck',
    author_email='trent@trenthauck.com',
    packages=['gloo'],
    scripts=[],
    url='http://pypi.python.org/pypi/Gloo/',
    license='LICENSE.txt',
    description='Project management for data analysis projects.',
    #install_requires=[],
    long_description=open('README.txt').read()
)
